##################################
Peek Platform - User Documentation
##################################

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    welcome
    doc_link/plugin_toc


Indices and tables
++++++++++++++++++

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

